==> hubzero-cms-1.3.1_1.3.1.0.orig.tar.gz: hubzero-cms-1.3.1-1.3.1.0/cms/components/com_collections/tables/collection.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

/**
 * Table class for collections
 */
class CollectionsTableCollection extends JTable
{
	/**
	 * Constructor
	 *
	 * @param   object  &$db  JDatabase
	 * @return  void
	 */
	public function __construct(&$db)
	{
		parent::__construct('#__collections', 'id', $db);
	}

	/**
	 * Load a record and bind to $this
	 *
	 * @param   mixed    $oid          Record alias
	 * @param   integer  $object_id    Object ID
	 * @param   string   $object_type  Object type
	 * @return  boolean  True on success
	 */
	public function load($oid=NULL, $object_id=null, $object_type=null)
	{
		if ($oid === NULL)
		{
			return false;
		}

		if (is_numeric($oid))
		{
			return parent::load($oid);
		}

		$fields = array(
			'alias'  => trim($oid)
		);

		$query = "SELECT * FROM $this->_tbl WHERE alias=" . $this->_db->Quote($oid);
		if ($object_id !== null)
		{
			$fields['object_id'] = intval($object_id);
		}
		if ($object_type !== null)
		{
			$fields['object_type'] = strtolower(trim($object_type));
		}

		return parent::load($fields);
	}

	/**
	 * Load a record by its alias and bind data to $this
	 *
	 * @param   integer  $object_id    Object ID
	 * @param   string   $object_type  Object type
	 * @return  boolean  True upon success, False if errors
	 */
	public function loadDefault($object_id=null, $object_type=null)
	{
		if (!$object_id || !$object_type)
		{
			return false;
		}

		$fields = array(
			'object_id'   => intval($object_id),
			'object_type' => trim($object_type),
			'is_default'  => 1
		);

		return parent::load($fields);
	}

	/**
	 * Populate the object with default data
	 *
	 * @param   integer  $object_id    Object ID
	 * @param   string   $object_type  Object type
	 * @return  boolean  True if data is bound to $this object
	 */
	public function setup($object_id=0, $object_type='')
	{
		$lang = JFactory::getLanguage();
		$lang->load('com_collections');

		$result = array(
			'id'          => 0,
			'title'       => JText::_('COM_COLLECTIONS_DEFAULT_TITLE'),
			'description' => JText::_('COM_COLLECTIONS_DEFAULT_DESC'),
			'object_id'   => $object_id,
			'object_type' => $object_type,
			'is_default'  => 1,
			'created_by'  => $object_id,
			'access'      => 4 // Private by default
		);
		if (!$result['created_by'])
		{
			$juser = JFactory::getUser();
			$result['created_by'] = $juser->get('id');
		}
		if (!$this->bind($result))
		{
			return false;
		}
		if (!$this->check())
		{
			return false;
		}
		if (!$this->store())
		{
			return false;
		}
		return $this->loadDefault($object_id, $object_type);
	}

	/**
	 * Validate data
	 *
	 * @return  boolean  True if data is valid
	 */
	public function check()
	{
		$this->title = trim($this->title);
		if (!$this->title)
		{
			$this->setError(JText::_('COM_COLLECTIONS_ERROR_MISSING_TITLE'));
			return false;
		}

		$this->alias = str_replace(' ', '-', strtolower($this->title));
		$this->alias = preg_replace("/[^a-zA-Z0-9\-]/", '', $this->alias);

		$this->object_id = intval($this->object_id);
		if (!$this->object_id)
		{
			$this->setError(JText::_('COM_COLLECTIONS_ERROR_MISSING_OBJECT_ID'));
			return false;
		}

		$this->object_type = trim($this->object_type);
		if (!$this->object_type)
		{
			$this->setError(JText::_('COM_COLLECTIONS_ERROR_MISSING_OBJECT_TYPE'));
			return false;
		}

		if ($this->access === null)
		{
			$this->access = 0;
		}

		$tbl = new CollectionsTableCollection($this->_db);
		$tbl->load($this->alias, $this->object_id, $this->object_type);

		if (!$this->id)
		{
			if ($tbl->id && $tbl->state != 2)
			{
				$this->setError(JText::_('COM_COLLECTIONS_ERROR_COLLECTION_EXISTS'));
				return false;
			}

			$juser = JFactory::getUser();
			$this->created    = ($this->created ? $this->created : JFactory::getDate()->toSql());
			$this->created_by = ($this->created_by ? $this->created_by : $juser->get('id'));
			$this->state      = 1;
		}
		else
		{
			if ($tbl->id
			 && $tbl->id != $this->id
			 && $tbl->state != 2)
			{
				$this->setError(JText::_('COM_COLLECTIONS_ERROR_COLLECTION_EXISTS'));
				return false;
			}
		}

		return true;
	}

	/**
	 * Build a query based off of filters passed
	 *
	 * @param   array   $filters  Filters to construct query from
	 * @return  string  SQL
	 */
	protected function _buildQuery($filters=array())
	{
		$query  = " FROM $this->_tbl AS b";
		$query .= " LEFT JOIN `#__collections_items` AS im ON im.type=" . $this->_db->Quote('collection') . " AND im.object_id=b.id";
		$query .= " LEFT JOIN `#__collections_following` AS f ON f.following_type=" . $this->_db->Quote('collection') . " AND f.following_id=b.id";
		if (isset($filters['user_id']) && $filters['user_id'])
		{
			$query .= " AND f.follower_type='member' AND f.follower_id=" . $this->_db->Quote($filters['user_id']);
		}
		if (isset($filters['object_type']) && $filters['object_type'] == 'group')
		{
			$query .= " LEFT JOIN `#__xgroups` AS g ON g.gidNumber=b.object_id AND b.object_type=" . $this->_db->Quote('group');
		}

		$where = array();

		if (isset($filters['item_id']) && $filters['item_id'])
		{
			$query .= " INNER JOIN #__collections_posts AS p ON p.collection_id=b.id";
			$where[] = "p.item_id=" . $this->_db->Quote($filters['item_id']);
			if (isset($filters['collection_id']))
			{
				if (is_array($filters['collection_id']))
				{
					$filters['collection_id'] = array_map('intval', $filters['collection_id']);
					$where[] = "b.id NOT IN (" . implode(',', $filters['collection_id']) . ")";
				}
				else if ($filters['collection_id'] > 0)
				{
					$where[] = "b.id != " . $this->_db->Quote(intval($filters['collection_id']));
				}
			}
		}

		if (isset($filters['state']) && $filters['state'] >= 0)
		{
			$where[] = "b.state=" . $this->_db->Quote(intval($filters['state']));
		}
		if (isset($filters['access']))
		{
			if (is_array($filters['access']))
			{
				$filters['access'] = array_map('intval', $filters['access']);
				$where[] = "b.access IN (" . implode(',', $filters['access']) . ")";
			}
			else if ($filters['access'] >= 0)
			{
				$where[] = "b.access=" . $this->_db->Quote(intval($filters['access']));
			}
		}
		if (isset($filters['is_default']) && $filters['is_default'] >= 0)
		{
			$where[] = "b.is_default=" . $this->_db->Quote(intval($filters['is_default']));
		}

		if (isset($filters['object_id']) && $filters['object_id'])
		{
			$where[] = "b.object_id=" . $this->_db->Quote(intval($filters['object_id']));
		}
		if (isset($filters['object_type']) && $filters['object_type'])
		{
			$where[] = "b.object_type=" . $this->_db->Quote($filters['object_type']);
		}

		if (isset($filters['created']) && $filters['created'])
		{
			$where[] = "b.created=" . $this->_db->Quote($filters['created']);
		}
		if (isset($filters['created_by']) && $filters['created_by'])
		{
			$where[] = "b.created_by=" . $this->_db->Quote(intval($filters['created_by']));
		}

		if (isset($filters['search']) && $filters['search'] != '')
		{
			$where[] = "(LOWER(b.title) LIKE " . $this->_db->quote('%' . strtolower($filters['search']) . '%') . ")";
		}

		if (count($where) > 0)
		{
			$query .= " WHERE " . implode(" AND ", $where);
		}

		return $query;
	}

	/**
	 * Return data based on a set of filters. Returned value 
	 * can be integer, object, or array
	 * 
	 * @param   string  $what
	 * @param   array   $filters
	 * @return  mixed
	 */
	public function find($what='', $filters=array())
	{
		$what = strtolower(trim($what));

		switch ($what)
		{
			case 'count':
				$query = "SELECT COUNT(DISTINCT b.id) " . $this->_buildQuery($filters);

				$this->_db->setQuery($query);
				return $this->_db->loadResult();
			break;

			case 'one':
				$filters['limit'] = 1;

				$result = null;
				if ($results = $this->find('list', $filters))
				{
					$result = $results[0];
				}

				return $result;
			break;

			case 'first':
				$filters['start'] = 0;
				$filters['limit'] = 1;

				$result = null;
				if ($results = $this->find('list', $filters))
				{
					$result = $results[0];
				}

				return $result;
			break;

			case 'all':
				if (isset($filters['limit']))
				{
					unset($filters['limit']);
				}
				return $this->find('list', $filters);
			break;

			case 'list':
			default:
				$access = "";
				if (isset($filters['access']))
				{
					if (is_array($filters['access']))
					{
						$filters['access'] = array_map('intval', $filters['access']);
						$access = "AND i.access IN (" . implode(',', $filters['access']) . ")";
					}
					else if ($filters['access'] >= 0)
					{
						$access = "AND i.access=" . $this->_db->Quote(intval($filters['access']));
					}
				}

				$query = "SELECT DISTINCT b.*, im.id AS item_id, im.positive AS likes, f.following_id AS following, (SELECT COUNT(*) FROM `#__collections_items` AS i INNER JOIN `#__collections_posts` AS s ON s.item_id=i.id WHERE s.collection_id=b.id AND i.state=1 $access) AS posts";
				if (isset($filters['object_type']) && $filters['object_type'] == 'group')
				{
					$query .= ", g.cn AS group_alias";
				}
				$query .= $this->_buildQuery($filters);

				if (!isset($filters['sort']) || !$filters['sort'])
				{
					$filters['sort'] = 'created';
				}
				if (!isset($filters['sort_Dir']) || !$filters['sort_Dir'])
				{
					$filters['sort_Dir'] = 'DESC';
				}
				$query .= " ORDER BY " . $filters['sort'] . " " . $filters['sort_Dir'];

				if (isset($filters['limit']) && $filters['limit'] > 0)
				{
					$filters['start'] = (isset($filters['start']) ? $filters['start'] : 0);

					$query .= " LIMIT " . (int) $filters['start'] . "," . (int) $filters['limit'];
				}

				$this->_db->setQuery($query);
				return $this->_db->loadObjectList();
			break;
		}
	}

	/**
	 * Get a record count
	 *
	 * @param   array    $filters  Filters to construct query from
	 * @return  integer
	 */
	public function getCount($filters=array())
	{
		return $this->find('count', $filters);
	}

	/**
	 * Get records
	 *
	 * @param   array  $filters  Filters to construct query from
	 * @return  array
	 */
	public function getRecords($filters=array())
	{
		return $this->find('list', $filters);
	}
}

==> hubzero-cms-1.3.1_1.3.1.7.orig.tar.gz: hubzero-cms-1.3.1-1.3.1.7/cms/components/com_collections/tables/collection.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

/**
 * Table class for collections
 */
class CollectionsTableCollection extends JTable
{
	/**
	 * Constructor
	 *
	 * @param   object  &$db  JDatabase
	 * @return  void
	 */
	public function __construct(&$db)
	{
		parent::__construct('#__collections', 'id', $db);
	}

	/**
	 * Load a record and bind to $this
	 *
	 * @param   mixed    $oid          Record alias
	 * @param   integer  $object_id    Object ID
	 * @param   string   $object_type  Object type
	 * @return  boolean  True on success
	 */
	public function load($oid=NULL, $object_id=null, $object_type=null)
	{
		if ($oid === NULL)
		{
			return false;
		}

		if (is_numeric($oid))
		{
			return parent::load($oid);
		}

		$query = "SELECT * FROM $this->_tbl WHERE state!=2 AND alias=" . $this->_db->Quote(trim($oid));
		if ($object_id !== null)
		{
			$query .= " AND object_id=" . $this->_db->Quote(intval($object_id));
		}
		if ($object_type !== null)
		{
			$query .= " AND object_type=" . $this->_db->Quote(strtolower(trim($object_type)));
		}

		$this->_db->setQuery($query);
		if ($result = $this->_db->loadAssoc())
		{
			return $this->bind($result);
		}
		else
		{
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
	}

	/**
	 * Load a record by its alias and bind data to $this
	 *
	 * @param   integer  $object_id    Object ID
	 * @param   string   $object_type  Object type
	 * @return  boolean  True upon success, False if errors
	 */
	public function loadDefault($object_id=null, $object_type=null)
	{
		if (!$object_id || !$object_type)
		{
			return false;
		}

		$fields = array(
			'object_id'   => intval($object_id),
			'object_type' => trim($object_type),
			'is_default'  => 1
		);

		return parent::load($fields);
	}

	/**
	 * Populate the object with default data
	 *
	 * @param   integer  $object_id    Object ID
	 * @param   string   $object_type  Object type
	 * @return  boolean  True if data is bound to $this object
	 */
	public function setup($object_id=0, $object_type='')
	{
		$lang = JFactory::getLanguage();
		$lang->load('com_collections');

		$result = array(
			'id'          => 0,
			'title'       => JText::_('COM_COLLECTIONS_DEFAULT_TITLE'),
			'description' => JText::_('COM_COLLECTIONS_DEFAULT_DESC'),
			'object_id'   => $object_id,
			'object_type' => $object_type,
			'is_default'  => 1,
			'created_by'  => $object_id,
			'access'      => 4 // Private by default
		);
		if (!$result['created_by'])
		{
			$juser = JFactory::getUser();
			$result['created_by'] = $juser->get('id');
		}
		if (!$this->bind($result))
		{
			return false;
		}
		if (!$this->check())
		{
			return false;
		}
		if (!$this->store())
		{
			return false;
		}
		return $this->loadDefault($object_id, $object_type);
	}

	/**
	 * Validate data
	 *
	 * @return  boolean  True if data is valid
	 */
	public function check()
	{
		$this->title = trim($this->title);
		if (!$this->title)
		{
			$this->setError(JText::_('COM_COLLECTIONS_ERROR_MISSING_TITLE'));
			return false;
		}

		$this->alias = str_replace(' ', '-', strtolower($this->title));
		$this->alias = preg_replace("/[^a-zA-Z0-9\-]/", '', $this->alias);

		$this->object_id = intval($this->object_id);
		if (!$this->object_id)
		{
			$this->setError(JText::_('COM_COLLECTIONS_ERROR_MISSING_OBJECT_ID'));
			return false;
		}

		$this->object_type = trim($this->object_type);
		if (!$this->object_type)
		{
			$this->setError(JText::_('COM_COLLECTIONS_ERROR_MISSING_OBJECT_TYPE'));
			return false;
		}

		if ($this->access === null)
		{
			$this->access = 0;
		}

		$tbl = new CollectionsTableCollection($this->_db);
		$tbl->load($this->alias, $this->object_id, $this->object_type);

		if (!$this->id)
		{
			if ($tbl->id && $tbl->state != 2)
			{
				$this->setError(JText::_('COM_COLLECTIONS_ERROR_COLLECTION_EXISTS'));
				return false;
			}

			$juser = JFactory::getUser();
			$this->created    = ($this->created ? $this->created : JFactory::getDate()->toSql());
			$this->created_by = ($this->created_by ? $this->created_by : $juser->get('id'));
			$this->state      = 1;
		}
		else
		{
			if ($tbl->id
			 && $tbl->id != $this->id
			 && $tbl->state != 2)
			{
				$this->setError(JText::_('COM_COLLECTIONS_ERROR_COLLECTION_EXISTS'));
				return false;
			}
		}

		return true;
	}

	/**
	 * Build a query based off of filters passed
	 *
	 * @param   array   $filters  Filters to construct query from
	 * @return  string  SQL
	 */
	protected function _buildQuery($filters=array())
	{
		$query  = " FROM $this->_tbl AS b";
		$query .= " LEFT JOIN `#__collections_items` AS im ON im.type=" . $this->_db->Quote('collection') . " AND im.object_id=b.id";
		$query .= " LEFT JOIN `#__collections_following` AS f ON f.following_type=" . $this->_db->Quote('collection') . " AND f.following_id=b.id";
		if (isset($filters['user_id']) && $filters['user_id'])
		{
			$query .= " AND f.follower_type='member' AND f.follower_id=" . $this->_db->Quote($filters['user_id']);
		}
		if (isset($filters['object_type']) && $filters['object_type'] == 'group')
		{
			$query .= " LEFT JOIN `#__xgroups` AS g ON g.gidNumber=b.object_id AND b.object_type=" . $this->_db->Quote('group');
		}

		$where = array();

		if (isset($filters['item_id']) && $filters['item_id'])
		{
			$query .= " INNER JOIN #__collections_posts AS p ON p.collection_id=b.id";
			$where[] = "p.item_id=" . $this->_db->Quote($filters['item_id']);
			if (isset($filters['collection_id']))
			{
				if (is_array($filters['collection_id']))
				{
					$filters['collection_id'] = array_map('intval', $filters['collection_id']);
					$where[] = "b.id NOT IN (" . implode(',', $filters['collection_id']) . ")";
				}
				else if ($filters['collection_id'] > 0)
				{
					$where[] = "b.id != " . $this->_db->Quote(intval($filters['collection_id']));
				}
			}
		}

		if (isset($filters['state']) && $filters['state'] >= 0)
		{
			$where[] = "b.state=" . $this->_db->Quote(intval($filters['state']));
		}
		if (isset($filters['access']))
		{
			if (is_array($filters['access']))
			{
				$filters['access'] = array_map('intval', $filters['access']);
				$where[] = "b.access IN (" . implode(',', $filters['access']) . ")";
			}
			else if ($filters['access'] >= 0)
			{
				$where[] = "b.access=" . $this->_db->Quote(intval($filters['access']));
			}
		}
		if (isset($filters['is_default']) && $filters['is_default'] >= 0)
		{
			$where[] = "b.is_default=" . $this->_db->Quote(intval($filters['is_default']));
		}

		if (isset($filters['object_id']) && $filters['object_id'])
		{
			$where[] = "b.object_id=" . $this->_db->Quote(intval($filters['object_id']));
		}
		if (isset($filters['object_type']) && $filters['object_type'])
		{
			$where[] = "b.object_type=" . $this->_db->Quote($filters['object_type']);
		}

		if (isset($filters['created']) && $filters['created'])
		{
			$where[] = "b.created=" . $this->_db->Quote($filters['created']);
		}
		if (isset($filters['created_by']) && $filters['created_by'])
		{
			$where[] = "b.created_by=" . $this->_db->Quote(intval($filters['created_by']));
		}

		if (isset($filters['search']) && $filters['search'] != '')
		{
			$where[] = "(LOWER(b.title) LIKE " . $this->_db->quote('%' . strtolower($filters['search']) . '%') . ")";
		}

		if (count($where) > 0)
		{
			$query .= " WHERE " . implode(" AND ", $where);
		}

		return $query;
	}

	/**
	 * Return data based on a set of filters. Returned value 
	 * can be integer, object, or array
	 * 
	 * @param   string  $what
	 * @param   array   $filters
	 * @return  mixed
	 */
	public function find($what='', $filters=array())
	{
		$what = strtolower(trim($what));

		switch ($what)
		{
			case 'count':
				$query = "SELECT COUNT(DISTINCT b.id) " . $this->_buildQuery($filters);

				$this->_db->setQuery($query);
				return $this->_db->loadResult();
			break;

			case 'one':
				$filters['limit'] = 1;

				$result = null;
				if ($results = $this->find('list', $filters))
				{
					$result = $results[0];
				}

				return $result;
			break;

			case 'first':
				$filters['start'] = 0;
				$filters['limit'] = 1;

				$result = null;
				if ($results = $this->find('list', $filters))
				{
					$result = $results[0];
				}

				return $result;
			break;

			case 'all':
				if (isset($filters['limit']))
				{
					unset($filters['limit']);
				}
				return $this->find('list', $filters);
			break;

			case 'list':
			default:
				$access = "";
				if (isset($filters['access']))
				{
					if (is_array($filters['access']))
					{
						$filters['access'] = array_map('intval', $filters['access']);
						$access = "AND i.access IN (" . implode(',', $filters['access']) . ")";
					}
					else if ($filters['access'] >= 0)
					{
						$access = "AND i.access=" . $this->_db->Quote(intval($filters['access']));
					}
				}

				$query = "SELECT DISTINCT b.*, im.id AS item_id, im.positive AS likes, f.following_id AS following, (SELECT COUNT(*) FROM `#__collections_items` AS i INNER JOIN `#__collections_posts` AS s ON s.item_id=i.id WHERE s.collection_id=b.id AND i.state=1 $access) AS posts";
				if (isset($filters['object_type']) && $filters['object_type'] == 'group')
				{
					$query .= ", g.cn AS group_alias";
				}
				$query .= $this->_buildQuery($filters);

				if (!isset($filters['sort']) || !$filters['sort'])
				{
					$filters['sort'] = 'created';
				}
				if (!isset($filters['sort_Dir']) || !$filters['sort_Dir'])
				{
					$filters['sort_Dir'] = 'DESC';
				}
				$query .= " ORDER BY " . $filters['sort'] . " " . $filters['sort_Dir'];

				if (isset($filters['limit']) && $filters['limit'] > 0)
				{
					$filters['start'] = (isset($filters['start']) ? $filters['start'] : 0);

					$query .= " LIMIT " . (int) $filters['start'] . "," . (int) $filters['limit'];
				}

				$this->_db->setQuery($query);
				return $this->_db->loadObjectList();
			break;
		}
	}

	/**
	 * Get a record count
	 *
	 * @param   array    $filters  Filters to construct query from
	 * @return  integer
	 */
	public function getCount($filters=array())
	{
		return $this->find('count', $filters);
	}

	/**
	 * Get records
	 *
	 * @param   array  $filters  Filters to construct query from
	 * @return  array
	 */
	public function getRecords($filters=array())
	{
		return $this->find('list', $filters);
	}
}
